@@ -8,25 +8,21 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef XCB_WRAPPER_H
-#define XCB_WRAPPER_H
+#pragma once
 
 #include <functional>
 #include <type_traits>
 
 #include <QScopedPointer>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
-#include <QX11Info>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 
 #include <xcb/randr.h>
 #include <xcb/xcb.h>
 
 namespace XCB
 {
-template<typename T> using ScopedPointer = QScopedPointer<T, QScopedPointerPodDeleter>;
+template<typename T>
+using ScopedPointer = QScopedPointer<T, QScopedPointerPodDeleter>;
 
 xcb_connection_t *connection();
 void closeConnection();
@@ -49,7 +45,7 @@ public:
         m_cookie.sequence = 0;
     }
 
-    explicit Wrapper(const RequestFuncArgs &... args)
+    explicit Wrapper(const RequestFuncArgs &...args)
         : m_retrieved(false)
         , m_cookie(requestFunc(connection(), args...))
         , m_window(requestWindow<RequestFuncArgs...>(args...))
@@ -172,7 +168,8 @@ private:
         }
     }
 
-    template<typename... Args> constexpr xcb_window_t requestWindow(const Args &... args) const
+    template<typename... Args>
+    constexpr xcb_window_t requestWindow(const Args &...args) const
     {
         return std::is_same<typename std::tuple_element<0, std::tuple<Args...>>::type, xcb_window_t>::value ? std::get<0>(std::tuple<Args...>(args...))
                                                                                                             : static_cast<xcb_window_t>(XCB_WINDOW_NONE);
@@ -209,5 +206,3 @@ XCB_DECLARE_TYPE(CRTCInfo, xcb_randr_get_crtc_info, xcb_randr_crtc_t, xcb_timest
 XCB_DECLARE_TYPE(AtomName, xcb_get_atom_name, xcb_atom_t);
 
 }
-
-#endif
